@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 # Copyright (c) 2011-2018 NAITOH Jun
 # Released under the MIT license
 # http://www.opensource.org/licenses/MIT
@@ -40,6 +41,7 @@ class RbpdfTest < Test::Unit::TestCase
     '026 : Text Rendering Modes and Text Clipping'          => '026',
     '028 : Changing page formats'                           => '028',
     '029 : Set PDF viewer display preferences.'             => '029',
+    '030 : Colour gradients'                                => '030',
     '031 : Pie Chart'                                       => '031',
     '033 : Mixed font types'                                => '033',
     '034 : Clipping'                                        => '034',
